![CI](https://github.com/iminders/fila/workflows/CI/badge.svg)
[![PyPI version](https://badge.fury.io/py/fila.svg)](https://badge.fury.io/py/fila)

# fila
Finance labeling(classification) algorithm baselines
